@@ -2,7 +2,7 @@ package DBIx::Class::InflateColumn::JSON2Object;
 
 # ABSTRACT: convert JSON columns to Perl objects
 
-our $VERSION = '0.902';
+our $VERSION = '0.903';
 
 use strict;
 use warnings;
@@ -12,36 +12,39 @@ use Module::Runtime 'use_module';
 use Scalar::Util qw(blessed);
 
 sub class_in_column {
-    my ($class,@args) = @_;
+    my ( $class, @args ) = @_;
     my $caller = caller(0);
 
     foreach my $def (@args) {
 
-        my $class_column    = $def->{class_column};
-        my $data_column     = $def->{data_column};
-        my $namespace       = $def->{namespace};
-        my $result_source   = $def->{result_source} || $caller;
+        my $class_column  = $def->{class_column};
+        my $data_column   = $def->{data_column};
+        my $namespace     = $def->{namespace};
+        my $result_source = $def->{result_source} || $caller;
 
         use_module($namespace);
 
         $result_source->inflate_column(
             $data_column,
-            {
-                inflate => sub {
-                    my ($data,$self) = @_;
-                    my $package = $namespace->package($self->$class_column);
+            {   inflate => sub {
+                    my ( $data, $self ) = @_;
+                    my $package = $namespace->package( $self->$class_column );
                     return $package->thaw($data);
                 },
                 deflate => sub {
-                    my ($data,$self) = @_;
-                    if (blessed $data) {
-                        if ($data->isa($namespace)) {
-                            $self->$class_column($data->moniker);
-                        } else {
-                            die('Supplied args object is not a '.$namespace);
+                    my ( $data, $self ) = @_;
+                    if ( blessed $data) {
+                        if ( $data->isa($namespace) ) {
+                            $self->$class_column( $data->moniker );
                         }
-                    } else {
-                        my $package = $namespace->package($self->$class_column);
+                        else {
+                            die( 'Supplied args object is not a '
+                                    . $namespace );
+                        }
+                    }
+                    else {
+                        my $package =
+                            $namespace->package( $self->$class_column );
                         $data = $package->thaw($data);
                     }
                     return $data->freeze;
@@ -52,7 +55,7 @@ sub class_in_column {
 }
 
 sub fixed_class {
-    my ($class,@args) = @_;
+    my ( $class, @args ) = @_;
     my $caller = caller(0);
 
     foreach my $def (@args) {
@@ -65,18 +68,18 @@ sub fixed_class {
 
         $result_source->inflate_column(
             $data_column,
-            {
-                inflate => sub {
-                    my ($data,$self) = @_;
+            {   inflate => sub {
+                    my ( $data, $self ) = @_;
                     return $package->thaw($data);
-            },
+                },
                 deflate => sub {
-                    my ($data,$self) = @_;
-                    if (blessed $data) {
-                        if (!$data->isa($package)) {
-                            die('Supplied args object is not a '.$package);
+                    my ( $data, $self ) = @_;
+                    if ( blessed $data) {
+                        if ( !$data->isa($package) ) {
+                            die('Supplied args object is not a ' . $package );
                         }
-                    } else {
+                    }
+                    else {
                         $data = $package->thaw($data);
                     }
                     return $data->freeze;
@@ -86,27 +89,76 @@ sub fixed_class {
     }
 }
 
-sub no_class {
-    my ($class,@args) = @_;
+sub array_of_class {
+    my ( $class, @args ) = @_;
     my $caller = caller(0);
 
     foreach my $def (@args) {
 
-        my $data_column     = $def->{column};
-        my $result_source   = $def->{result_source} || $caller;
+        my $data_column   = $def->{column};
+        my $package       = $def->{class};
+        my $result_source = $def->{result_source} || $caller;
+
+        use_module($package);
 
         $result_source->inflate_column(
             $data_column,
-            {
-                inflate => sub {
-                    my ($data,$self) = @_;
+            {   inflate => sub {
+                    my ( $raw_list, $self ) = @_;
+                    utf8::encode($raw_list) if utf8::is_utf8($raw_list);
+                    my $list = decode_json($raw_list);
+                    die('Can only work with arrayref')
+                        unless ref($list) eq 'ARRAY';
+                    my @objects;
+                    foreach my $data (@$list) {
+                        push( @objects, $package->new($data) );
+                    }
+                    return \@objects;
+                },
+                deflate => sub {
+                    my ( $list, $self ) = @_;
+                    die('Supplied args object is not a arrayref')
+                        unless ref($list) eq 'ARRAY';
+                    my @frozen;
+                    foreach my $data (@$list) {
+                        if ( blessed $data) {
+                            if ( !$data->isa($package) ) {
+                                die( 'Supplied args object is not a '
+                                        . $package );
+                            }
+                        }
+                        else {
+                            $data = $package->thaw($data);
+                        }
+                        push( @frozen, $data->freeze );
+                    }
+                    return '[' . ( join( ',', @frozen ) ) . ']';
+                },
+            }
+        );
+    }
+}
+
+sub no_class {
+    my ( $class, @args ) = @_;
+    my $caller = caller(0);
+
+    foreach my $def (@args) {
+
+        my $data_column = $def->{column};
+        my $result_source = $def->{result_source} || $caller;
+
+        $result_source->inflate_column(
+            $data_column,
+            {   inflate => sub {
+                    my ( $data, $self ) = @_;
                     return {}
                         if !defined $data
-                            || $data =~ m/^\s*$/;
+                        || $data =~ m/^\s*$/;
                     return decode_json( encode_utf8($data) );
                 },
                 deflate => sub {
-                    my ($data,$self) = @_;
+                    my ( $data, $self ) = @_;
                     if ( ref($data) =~ m/^(HASH|ARRAY)$/ ) {
                         return decode_utf8( encode_json($data) );
                     }
@@ -131,7 +183,7 @@ DBIx::Class::InflateColumn::JSON2Object - convert JSON columns to Perl objects
 
 =head1 VERSION
 
-version 0.902
+version 0.903
 
 =head1 SYNOPSIS
 
@@ -169,6 +221,12 @@ version 0.902
       namespace    => 'MyApp::Object', # the namespace of the objects
   });
 
+  # or store a list of objects (of one class!) into an array
+  DBIx::Class::InflateColumn::JSON2Object->array_of_class({
+      column=>'data',      # a column storing a JSON list
+      class=>'MyApp::SomeElementClass',
+  });
+
 =head1 DESCRIPTION
 
 TODO: short overview
@@ -238,6 +296,20 @@ To get back the object:
 
   TODO
 
+=head3 array_in_class
+
+Sometimes you want to store a list of objects without packing them into a "Set"-Object. This only works if all objects are of the same class, as we do not want to include the class name inside the object (c.f. MooseX::Storage, KiokuDB).
+
+ TODO ->array_in_class(..)
+
+Just pass an arrayref of object to the row and it will be stored as JSON:
+
+  TODO
+
+And you get back the initated list of objects:
+
+  TODO
+
 =head1 THANKS
 
 =over
